React Starter Template
Author: Reactonite
Description: Reactonite starter template page

# Features

Reactonite is a Free and Open Source tool that let's you build React Apps using vanilla HTML code and convert it to a React code easily, hence building a PWA, SPA. The main aim of Reactonite is to create a starter multi/single page React apps based on a HTML file provided by the user, however, we have extended it's functionality to some drag and drop based website generator. This allows even not so experienced developers build SPAs and PWAs on the fly. We have one of the best documentation for Reactonite to get you up and running is seconds. View Docs.

Fig 1. Reactonite Documentation

Fig 2. HTML code fed into Reactonite

Fig 3. Transpiled code generated by Reactonite

## Design Specs

Reactonite provides a simple CLI to handle everything from the commandline itslef. The CLI is used to either start realtime development servers or generate a static build of the website.

As shown in Fig 4. below the Reactonite CLI connects to GrapeJs UI builder which generates HTML and Static files for the website, however, one can simply skip this and use their own HTML website. Changes in files are tracked by WatchDog in realtime and Reactonite transpiles the codebase automatically. As we have a NodeJs server running for React again wrapped using Reactonite, these changes are Hot Reloaded on the screen. The output is the corresponding React codebase which is very readable as we try our best to not change the directory structure and varibale names much, along with a SPA or PWA which can be build and deployed onto a server or Github Pages.

Fig 4. Reactonite workflow for Transpilation